#ifndef R_COLOURVALUES_COLOURS_H
#define R_COLOURVALUES_COLOURS_H

#include "colourvalues/scale/scale.hpp"
#include "colourvalues/utils/utils.hpp"
#include "colourvalues/palette_utils/palette_utils.hpp"
#include "colourvalues/convert/convert_colours.hpp"

//#include <boost/math/interpolators/cardinal_cubic_b_spline.hpp>


#endif
